// init.h

#ifndef __INIT_H
#define __INIT_H

#include "colorlib.h"  // For the 'colorlist'

// The red, green and blue triple of the current color.
extern int rgb[3];

// The picklist containing all of the colors from the file
extern Widget list;

// Initialize the widgets
void Init(Widget);

// When you give this function a red, green and blue, it will return
// the index to the descriptor which is nearest the color triplet specified.
int ClosestColor(int *, int *, int *);

// Called when the return is pressed in a text box. 
void ReturnAction(Widget, XEvent*, String*, Cardinal*);

#endif

